Eine aktuelle Version dieser Datei befindet sich auf unserer Wikiseite.

# Quizdrill

OpenFacts, the Open Source Knowledge Database

Quizdrill is a learning-by-testing program to learn quickly, mostly memorizing tasks like vocabulary. Quizdrill supports multiple choice, simple quiz as well as flashcard testing. Although still quite immature, Quizdrill asks questions which have been answered right more often then others, less often to improve learning efficiency. Quizzes can be easily created by edition simple text files or automatically built from Infobox-style templates of Wikipedia dumps (or other MediaWikis and even Semantic MediaWikis). Quizdrill tries to be as easy to use as possible.

Quizdrill should run on Linux, Mac/OSX, Unixes and Window. Install includes more information. For bug reports and feature requests see the Quizdrill project page. Quizdrill is released under the GNU GPL either version 2 of the License, or (at your option) any later version.

## Contents

- Install
- Usage
- Writing Quizzes
- List of Quizzes
- Similar Programs

### Development

- Hacking